# Changelog

## 1.0.0 (2021-09-07)

#### Others

* add changelog

Full set of changes: [`0.10.0-dev4...1.0.0`](https://github.com/unikubehq/cli/compare/0.10.0-dev4...1.0.0)

## 0.10.0-dev4 (2021-09-03)


Full set of changes: [`0.10.0-dev3...0.10.0-dev4`](https://github.com/unikubehq/cli/compare/0.10.0-dev3...0.10.0-dev4)

## 0.10.0-dev3 (2021-09-03)


Full set of changes: [`0.10.0-dev2...0.10.0-dev3`](https://github.com/unikubehq/cli/compare/0.10.0-dev2...0.10.0-dev3)

## 0.10.0-dev2 (2021-09-01)

#### Fixes

* check if switched container is running for shell command ([#121](https://github.com/unikubehq/cli/issues/121))
#### Docs

* fix sentence

Full set of changes: [`0.10.0-dev1...0.10.0-dev2`](https://github.com/unikubehq/cli/compare/0.10.0-dev1...0.10.0-dev2)

## 0.10.0-dev1 (2021-08-27)

#### Docs

* fix typos, small rewrites ([#118](https://github.com/unikubehq/cli/issues/118))
* fix typo

Full set of changes: [`0.9.0-dev11...0.10.0-dev1`](https://github.com/unikubehq/cli/compare/0.9.0-dev11...0.10.0-dev1)

## 0.9.0-dev11 (2021-08-26)

#### Docs

* fix typos, add few hints

Full set of changes: [`0.9.0-dev10...0.9.0-dev11`](https://github.com/unikubehq/cli/compare/0.9.0-dev10...0.9.0-dev11)

## 0.9.0-dev10 (2021-08-26)

#### Docs

* add missing references

Full set of changes: [`0.9.0-dev9...0.9.0-dev10`](https://github.com/unikubehq/cli/compare/0.9.0-dev9...0.9.0-dev10)

## 0.9.0-dev9 (2021-08-26)

#### Fixes

* remove help arg from click.argument

Full set of changes: [`0.9.0-dev8...0.9.0-dev9`](https://github.com/unikubehq/cli/compare/0.9.0-dev8...0.9.0-dev9)

## 0.9.0-dev8 (2021-08-26)

#### Docs

* add another hint

Full set of changes: [`0.9.0-dev7...0.9.0-dev8`](https://github.com/unikubehq/cli/compare/0.9.0-dev7...0.9.0-dev8)

## 0.9.0-dev7 (2021-08-26)

#### Docs

* fix merge mess
* move text and docs structure, add a lot of documentation
* move text and docs structure, add a lot of documentation
* adds even more basic documentation
* delete redundant docs

Full set of changes: [`0.9.0-dev6...0.9.0-dev7`](https://github.com/unikubehq/cli/compare/0.9.0-dev6...0.9.0-dev7)

## 0.9.0-dev6 (2021-08-26)

#### New Features

* duplicate project title
* duplicate project title
* showing specific error message if project cannot be retrieved
* exit on error with specified message
#### Fixes

* missing imports from helpers
* remove list as parameter
* fixes for minor problems
* project up inconsistency
* fixes for minor problems
* project up inconsistency
* test errors for DistributionNotFound
* version check error
* invalid context error mesage
* invalid context error mesage
#### Refactorings

* change console info
* consolidate project use tests
* change console info
* consolidate project use tests
* remove exit_error_with_message()
* remove exit_error_with_message()
* remove exit_error_with_message()
* remove exit_error_with_message()
#### Others

* adjust tests
* added new tests for helpers

Full set of changes: [`0.9.0-dev4...0.9.0-dev6`](https://github.com/unikubehq/cli/compare/0.9.0-dev4...0.9.0-dev6)

## 0.9.0-dev4 (2021-07-16)

#### New Features

* showing specific error message if project cannot be retrieved
* exit on error with specified message
#### Fixes

* login state in test
* login test
* app switch deck_id
* deck selection
* typo ([#68](https://github.com/unikubehq/cli/issues/68))
* take namespace from environment instead of deck for KubeAPI when uninstalling deck
#### Others

* add real login test
* added new tests for helpers

Full set of changes: [`0.9.0-dev3...0.9.0-dev4`](https://github.com/unikubehq/cli/compare/0.9.0-dev3...0.9.0-dev4)

## 0.9.0-dev3 (2021-06-28)

#### Fixes

* take namespace from environment instead of deck for KubeAPI

Full set of changes: [`0.9.0-dev2...0.9.0-dev3`](https://github.com/unikubehq/cli/compare/0.9.0-dev2...0.9.0-dev3)

## 0.9.0-dev2 (2021-06-28)

#### New Features

* add info for running project up command
* exec as shell alias
* exec as shell alias
#### Fixes

* add oic to requirem
* updating requirement for a higher version of PyYAML
* sonarcloud detected bugs
* create cluster spinner added
* code smell commented code
* install coveralls and add to requirements
* code smells with nested empty function
* install coverage
* create cluster spinner added
#### Docs

* add coverage badge
#### Others

* run black on new files, fix flake8
* pin pyyaml to >=5.4 in setup.py
* add pytest to workflow
* test orga command
* test text
* comment failing tests
* update workflows and add coveragerc file
* add tests for app, auth, system commands

Full set of changes: [`0.8.1-dev13...0.9.0-dev2`](https://github.com/unikubehq/cli/compare/0.8.1-dev13...0.9.0-dev2)

## 0.8.1-dev13 (2021-06-14)

#### Fixes

* app switch command to clean docker processes after

Full set of changes: [`0.8.1-dev12...0.8.1-dev13`](https://github.com/unikubehq/cli/compare/0.8.1-dev12...0.8.1-dev13)

## 0.8.1-dev12 (2021-06-14)

#### Fixes

* app switch command to build docker for projects with whitespace
* follow flag
#### Refactorings

* rename function

Full set of changes: [`0.8.1-dev10...0.8.1-dev12`](https://github.com/unikubehq/cli/compare/0.8.1-dev10...0.8.1-dev12)

## 0.8.1-dev10 (2021-06-11)

#### Fixes

* adds spinner to setup.py

Full set of changes: [`0.8.1-dev9...0.8.1-dev10`](https://github.com/unikubehq/cli/compare/0.8.1-dev9...0.8.1-dev10)

## 0.8.1-dev9 (2021-06-09)

#### New Features

* include context in commands
#### Fixes

* get at least 100 decks (paginator still missing)
* (login): AUTH_DEFAULT_HOST can be changed
#### Refactorings

* (context): GraphQL request

Full set of changes: [`0.8.1-dev8...0.8.1-dev9`](https://github.com/unikubehq/cli/compare/0.8.1-dev8...0.8.1-dev9)

## 0.8.1-dev8 (2021-06-01)


Full set of changes: [`0.8.1-dev7...0.8.1-dev8`](https://github.com/unikubehq/cli/compare/0.8.1-dev7...0.8.1-dev8)

## 0.8.1-dev7 (2021-06-01)

#### Docs

* add pre-release notice

Full set of changes: [`0.8.1-dev6...0.8.1-dev7`](https://github.com/unikubehq/cli/compare/0.8.1-dev6...0.8.1-dev7)

## 0.8.1-dev6 (2021-06-01)

#### Docs

* add cloudbuild config

Full set of changes: [`0.8.1-dev5...0.8.1-dev6`](https://github.com/unikubehq/cli/compare/0.8.1-dev5...0.8.1-dev6)

## 0.8.1-dev5 (2021-06-01)


Full set of changes: [`0.8.1-dev4...0.8.1-dev5`](https://github.com/unikubehq/cli/compare/0.8.1-dev4...0.8.1-dev5)

## 0.8.1-dev4 (2021-06-01)

#### Docs

* fixunikube logo image

Full set of changes: [`0.8.1-dev3...0.8.1-dev4`](https://github.com/unikubehq/cli/compare/0.8.1-dev3...0.8.1-dev4)

## 0.8.1-dev3 (2021-06-01)

#### Docs

* change unikube logo image

Full set of changes: [`0.8.1-dev2...0.8.1-dev3`](https://github.com/unikubehq/cli/compare/0.8.1-dev2...0.8.1-dev3)

## 0.8.1-dev2 (2021-06-01)

#### Docs

* add long desription to package

Full set of changes: [`0.8.1-dev1...0.8.1-dev2`](https://github.com/unikubehq/cli/compare/0.8.1-dev1...0.8.1-dev2)

## 0.8.1-dev1 (2021-06-01)

#### New Features

* (context): package use added
* adds batches in readme
* adds github workflows
* initial release
#### Fixes

* correct helper string
* correct sonarcloud batch
#### Docs

* fix readme links
#### Others

* add github pypi publish workflow
* run black
